

dkjason - Helper module to send json encoded data from Python
=============================================================

This module knows how to serialize general object, objects specialized
with a ``__json__()`` method, Django QuerySets, and ``ttcal`` objects.

.. image:: https://gitlab.com/norsktest/dkjason/badges/master/pipeline.svg
   :target: https://gitlab.com/norsktest/dkjason/commits/master
   :alt: pipeline status

.. image:: https://img.shields.io/badge/docs-darkgreen.svg
   :target: https://norsktest.gitlab.io/dkjason

.. image:: https://gitlab.com/norsktest/dkjason/badges/master/coverage.svg
   :target: https://norsktest.gitlab.io/dkjason/coverage
   :alt: coverage report

.. image:: https://codecov.io/gl/norsktest/dkjason/branch/master/graph/badge.svg?token=zmqdQHOX89
   :target: https://codecov.io/gl/norsktest/dkjason

